@@ -3,6 +3,7 @@ from pprint import pprint
 from pathlib import Path
 from subprocess import run
 import yaml
+import toml
 import os
 from making_with_code_cli.mwc_api import MakingWithCodeAPI as API
 from making_with_code_cli.styles import (
@@ -45,14 +46,13 @@ from making_with_code_cli.git_backend import (
 @click.group()
 def cli():
     "Command line interface for Making with Code."
-    pass
 
-#@cli.command()
-def home():
-    "Go to the MWC home folder"
-    settings = read_settings()
-    print(settings["work_dir"])
-    os.chdir(settings["work_dir"])
+@cli.command()
+def version():
+    "Print MWC version"
+    config = toml.loads(Path("pyproject.toml").read_text())
+    version = config['tool']['poetry']['version']
+    click.echo(address("MWC " + version, preformatted=True))
 
 @cli.command()
 @click.option("--yes", is_flag=True, help="Automatically answer 'yes' to setup prompts")
@@ -118,8 +118,11 @@ def update():
             unit_dir.mkdir(mode=WORK_DIR_PERMISSIONS, exist_ok=True)
             for module in unit['modules']:
                 module_dir = unit_dir / module['slug']
-                if not module_dir.exists() and 'init_action' in module:
-                    rel_dir = module_dir.resolve().relative_to(mwc_home)
-                    msg = f"Initializing {module['slug']} at {rel_dir}. See {module['url']} for details."
-                    click.echo(confirm(msg))
-                    G.init_module(module, module_dir)
+                if module_dir.exists():
+                    G.update(module, module_dir)
+                else:
+                    if 'init_action' in module:
+                        rel_dir = module_dir.resolve().relative_to(mwc_home)
+                        msg = f"Initializing {module['slug']} at {rel_dir}. See {module['url']} for details."
+                        click.echo(confirm(msg))
+                        G.init_module(module, module_dir)
