@@ -246,9 +246,6 @@ class WriteShellConfig(SetupTask):
         with get_mwc_rc_path().open('w') as fh:
             shell = get_shell_name()
             fh.write("# Making With Code RC File\n\n")
-            if Platform.detect() == Platform.MAC:
-                fh.write("## Add mwc to path\n")
-                fh.write('export PATH="$HOME/Library/Python/3.9/bin:$PATH"\n\n')
             fh.write("## Add Poetry to $PATH\n")
             fh.write('export PATH="$HOME/.local/bin:$PATH"\n\n')
             if Platform.detect() == Platform.MAC and self.settings['editor'] == "subl":
